<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Careerpress Pro
 * @since Careerpress Pro 1.0.0
 */

if ( ! function_exists( 'careerpress_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Careerpress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function careerpress_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'careerpress_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'careerpress_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Careerpress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function careerpress_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'careerpress_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'careerpress_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Careerpress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function careerpress_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'careerpress_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[slider_content_type]' )->value();
	return careerpress_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[slider_content_type]' )->value();
	return careerpress_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[slider_content_type]' )->value();
	return careerpress_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[service_content_type]' )->value();
	return careerpress_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[service_content_type]' )->value();
	return careerpress_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[service_content_type]' )->value();
	return careerpress_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[service_content_type]' )->value();
	return careerpress_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[about_content_type]' )->value();
	return careerpress_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[about_content_type]' )->value();
	return careerpress_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[about_content_type]' )->value();
	return careerpress_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[cta_content_type]' )->value();
	return careerpress_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[cta_content_type]' )->value();
	return careerpress_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[cta_content_type]' )->value();
	return careerpress_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if features section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_features_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[features_section_enable]' )->value() );
}

/**
 * Check if features section content type is category.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_features_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[features_content_type]' )->value();
	return careerpress_pro_is_features_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if features section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_features_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[features_content_type]' )->value();
	return careerpress_pro_is_features_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if features section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_features_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[features_content_type]' )->value();
	return careerpress_pro_is_features_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if features section seperator.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_features_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[features_content_type]' )->value();
	return careerpress_pro_is_features_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if projects section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_projects_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[projects_section_enable]' )->value() );
}

/**
 * Check if projects section content type is category.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_projects_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[projects_content_type]' )->value();
	return careerpress_pro_is_projects_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if projects section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_projects_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[projects_content_type]' )->value();
	return careerpress_pro_is_projects_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if projects section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_projects_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[projects_content_type]' )->value();
	return careerpress_pro_is_projects_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section seperator.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[team_content_type]' )->value();
	return careerpress_pro_is_team_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[team_content_type]' )->value();
	return careerpress_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[team_content_type]' )->value();
	return careerpress_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[team_content_type]' )->value();
	return careerpress_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

// /**
//  * Check if team section content type is position.
//  *
//  * @since Careerpress Pro 1.0.0
//  * @param WP_Customize_Control $control WP_Customize_Control instance.
//  * @return bool Whether the control is active to the current preview.
//  */
// function careerpress_pro_is_team_section_content_position_enable( $control ) {
// 	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[team_content_type]' )->value();
// 	return careerpress_pro_is_team_section_enable( $control ) && ( 'category' !== $content_type );
// }

/**
 * Check if team section content type is custom.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[team_content_type]' )->value();
	return careerpress_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[testimonial_content_type]' )->value();
	return careerpress_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[testimonial_content_type]' )->value();
	return careerpress_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[testimonial_content_type]' )->value();
	return careerpress_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[testimonial_content_type]' )->value();
	return careerpress_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

// /**
//  * Check if testimonial section content type is position.
//  *
//  * @since Careerpress Pro 1.0.0
//  * @param WP_Customize_Control $control WP_Customize_Control instance.
//  * @return bool Whether the control is active to the current preview.
//  */
// function careerpress_pro_is_testimonial_section_content_position_enable( $control ) {
// 	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[testimonial_content_type]' )->value();
// 	return careerpress_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
// }

/**
 * Check if testimonial section content type is custom.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[testimonial_content_type]' )->value();
	return careerpress_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if client section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_client_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[client_section_enable]' )->value() );
}

/**
 * Check if client section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_client_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[client_content_type]' )->value();
	return careerpress_pro_is_client_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if client section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_client_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[client_content_type]' )->value();
	return careerpress_pro_is_client_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if client section content type is category.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_client_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[client_content_type]' )->value();
	return careerpress_pro_is_client_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if client section content type is custom.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_client_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[client_content_type]' )->value();
	return careerpress_pro_is_client_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[blog_content_type]' )->value();
	return careerpress_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[blog_content_type]' )->value();
	return careerpress_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[blog_content_type]' )->value();
	return careerpress_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[blog_content_type]' )->value();
	return careerpress_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if promotion section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_promotion_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[promotion_section_enable]' )->value() );
}

/**
 * Check if promotion section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_promotion_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[promotion_content_type]' )->value();
	return careerpress_pro_is_promotion_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if promotion section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_promotion_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[promotion_content_type]' )->value();
	return careerpress_pro_is_promotion_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if promotion section content type is custom.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_promotion_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[promotion_content_type]' )->value();
	return careerpress_pro_is_promotion_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if counter section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[counter_section_enable]' )->value() );
}


//featured section
function careerpress_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[featured_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}


/**
 * Check if product section is enabled.
 *
 * @since Careerpress Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if product section content type is product.
 *
 * @since Careerpress Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[product_content_type]' )->value();
	return careerpress_pro_is_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product section content type is product category.
 *
 * @since Careerpress Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[product_content_type]' )->value();
	return careerpress_pro_is_product_section_enable( $control ) && ( 'product-category' == $content_type );
}


/**
 * Check if latest_product section is enabled.
 *
 * @since Careerpress Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_latest_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[latest_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if latest_product section content type is latest_product.
 *
 * @since Careerpress Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_latest_product_section_content_latest_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[latest_product_content_type]' )->value();
	return careerpress_pro_is_latest_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if latest_product section content type is latest_product category.
 *
 * @since Careerpress Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_latest_product_section_content_latest_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[latest_product_content_type]' )->value();
	return careerpress_pro_is_latest_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

function careerpress_pro_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[subscription_section_enable]' )->value() );
}

/**
 * Check if video section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if video section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[video_content_type]' )->value();
	return careerpress_pro_is_video_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[video_content_type]' )->value();
	return careerpress_pro_is_video_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if video section content type is custom.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_video_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[video_content_type]' )->value();
	return careerpress_pro_is_video_section_enable( $control ) && ( 'custom' == $content_type );
}


/*course section*/

/**
 * Check if course section is enabled.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'careerpress_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is category.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[course_content_type]' )->value();
	return careerpress_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[course_content_type]' )->value();
	return careerpress_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is post.
 *
 * @since Careerpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function careerpress_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'careerpress_pro_theme_options[course_content_type]' )->value();
	return careerpress_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}
