<?php
/**
 * Product Section options
 *
 * @package Theme Palace
 * @subpackage Careerpress Pro
 * @since Careerpress Pro 1.0.0
 */

// Add Product section
$wp_customize->add_section( 'careerpress_pro_product_section', array(
	'title'             => esc_html__( 'Recent Product','careerpress-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'careerpress-pro' ),
	'panel'             => 'careerpress_pro_front_page_panel',
) );

// Product content enable control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[product_section_enable]', array(
	'default'			=> 	$options['product_section_enable'],
	'sanitize_callback' => 'careerpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Careerpress_Pro_Switch_Control( $wp_customize, 'careerpress_pro_theme_options[product_section_enable]', array(
	'label'             => esc_html__( 'Recent Product Section Enable', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_product_section',
	'on_off_label' 		=> careerpress_pro_switch_options(),
) ) );

// product title setting and control
$wp_customize->add_setting( 'careerpress_pro_theme_options[product_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['product_title'],
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[product_title]', array(
	'label'           	=> esc_html__( 'Title', 'careerpress-pro' ),
	'section'        	=> 'careerpress_pro_product_section',
	'active_callback' 	=> 'careerpress_pro_is_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'careerpress_pro_theme_options[product_title]', array(
		'selector'            => '#recent-products .section-header h2',
		'settings'            => 'careerpress_pro_theme_options[product_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'careerpress_pro_product_title_partial',
    ) );
}

// product subtitle setting and control
$wp_customize->add_setting( 'careerpress_pro_theme_options[product_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['product_subtitle'],
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[product_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'careerpress-pro' ),
	'section'        	=> 'careerpress_pro_product_section',
	'active_callback' 	=> 'careerpress_pro_is_product_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'careerpress_pro_theme_options[product_subtitle]', array(
		'selector'            => '#recent-products .section-header P',
		'settings'            => 'careerpress_pro_theme_options[product_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'careerpress_pro_product_subtitle_partial',
    ) );
}


// Product content type control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[product_content_type]', array(
	'default'          	=> $options['product_content_type'],
	'sanitize_callback' => 'careerpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[product_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'careerpress_pro_is_product_section_enable',
	'choices'			=> careerpress_pro_product_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[product_count]', array(
	'default'          	=> $options['product_count'],
	'sanitize_callback' => 'careerpress_pro_sanitize_number_range',
	'validate_callback' => 'careerpress_pro_validate_product_count',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[product_count]', array(
	'label'             => esc_html__( 'Number of Product', 'careerpress-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_product_section',
	'active_callback'   => 'careerpress_pro_is_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['product_count']; $i++ ) :

	// product posts drop down chooser control and setting
	$wp_customize->add_setting( 'careerpress_pro_theme_options[product_content_product_' . $i . ']', array(
		'sanitize_callback' => 'careerpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Careerpress_Pro_Dropdown_Chooser( $wp_customize, 'careerpress_pro_theme_options[product_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'careerpress-pro' ), $i ),
		'section'           => 'careerpress_pro_product_section',
		'choices'			=> careerpress_pro_product_choices(),
		'active_callback'	=> 'careerpress_pro_is_product_section_content_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'careerpress_pro_theme_options[product_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Careerpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'careerpress_pro_theme_options[product_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'careerpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_product_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'careerpress_pro_is_product_section_content_product_category_enable'
) ) );
